Module: Google::Apis::MerchantapiReviewsV1beta
- Defined in:
- lib/google/apis/merchantapi_reviews_v1beta.rb,
lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/service.rb,
lib/google/apis/merchantapi_reviews_v1beta/gem_version.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb
Overview
Merchant API
Programmatically manage your Merchant Center Accounts.
Defined Under Namespace
Classes: CustomAttribute, Empty, ListMerchantReviewsResponse, ListProductReviewsResponse, MerchantReview, MerchantReviewAttributes, MerchantReviewDestinationStatus, MerchantReviewItemLevelIssue, MerchantReviewStatus, MerchantService, ProductChange, ProductReview, ProductReviewAttributes, ProductReviewDestinationStatus, ProductReviewItemLevelIssue, ProductReviewStatus, ProductStatusChangeMessage, ReviewLink
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-merchantapi_reviews_v1beta gem
"0.11.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260527"- VERSION =
Version of the Merchant API this client connects to. This is NOT the gem version.
'ReviewsV1beta'- AUTH_CONTENT =
Manage your product listings and accounts for Google Shopping
'https://www.googleapis.com/auth/content'