Class: Google::Apis::MerchantapiReviewsV1beta::ProductReviewAttributes
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReviewsV1beta::ProductReviewAttributes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb
Overview
Attributes.
Instance Attribute Summary collapse
-
#aggregator_name ⇒ String
Optional.
-
#asins ⇒ Array<String>
Optional.
-
#brands ⇒ Array<String>
Optional.
-
#collection_method ⇒ String
Optional.
-
#cons ⇒ Array<String>
Optional.
-
#content ⇒ String
Optional.
-
#gtins ⇒ Array<String>
Optional.
-
#is_incentivized_review ⇒ Boolean
(also: #is_incentivized_review?)
Optional.
-
#is_spam ⇒ Boolean
(also: #is_spam?)
Optional.
-
#is_verified_purchase ⇒ Boolean
(also: #is_verified_purchase?)
Optional.
-
#max_rating ⇒ Fixnum
Optional.
-
#min_rating ⇒ Fixnum
Optional.
-
#mpns ⇒ Array<String>
Optional.
-
#product_links ⇒ Array<String>
Optional.
-
#product_names ⇒ Array<String>
Optional.
-
#pros ⇒ Array<String>
Optional.
-
#publisher_favicon ⇒ String
Optional.
-
#publisher_name ⇒ String
Optional.
-
#rating ⇒ Float
Optional.
-
#review_country ⇒ String
Optional.
-
#review_language ⇒ String
Optional.
-
#review_link ⇒ Google::Apis::MerchantapiReviewsV1beta::ReviewLink
The URI of the review landing page.
-
#review_time ⇒ String
Required.
-
#reviewer_id ⇒ String
Optional.
-
#reviewer_image_links ⇒ Array<String>
Optional.
-
#reviewer_is_anonymous ⇒ Boolean
(also: #reviewer_is_anonymous?)
Optional.
-
#reviewer_username ⇒ String
Optional.
-
#skus ⇒ Array<String>
Optional.
-
#subclient_name ⇒ String
Optional.
-
#title ⇒ String
Optional.
-
#transaction_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductReviewAttributes
constructor
A new instance of ProductReviewAttributes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductReviewAttributes
Returns a new instance of ProductReviewAttributes.
715 716 717 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregator_name ⇒ String
Optional. The name of the aggregator of the product reviews. A publisher may
use a reviews aggregator to manage reviews and provide the feeds. This element
indicates the use of an aggregator and contains information about the
aggregator.
Corresponds to the JSON property aggregatorName
538 539 540 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 538 def aggregator_name @aggregator_name end |
#asins ⇒ Array<String>
Optional. Contains ASINs (Amazon Standard Identification Numbers) associated
with a product.
Corresponds to the JSON property asins
544 545 546 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 544 def asins @asins end |
#brands ⇒ Array<String>
Optional. Contains brand names associated with a product.
Corresponds to the JSON property brands
549 550 551 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 549 def brands @brands end |
#collection_method ⇒ String
Optional. The method used to collect the review.
Corresponds to the JSON property collectionMethod
554 555 556 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 554 def collection_method @collection_method end |
#cons ⇒ Array<String>
Optional. Contains the disadvantages based on the opinion of the reviewer.
Omit boilerplate text like "con:" unless it was written by the reviewer.
Corresponds to the JSON property cons
560 561 562 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 560 def cons @cons end |
#content ⇒ String
Optional. The content of the review. If empty, the content might still get
populated from pros and cons.
Corresponds to the JSON property content
566 567 568 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 566 def content @content end |
#gtins ⇒ Array<String>
Optional. Contains GTINs (global trade item numbers) associated with a product.
Sub-types of GTINs (e.g. UPC, EAN, ISBN, JAN) are supported.
Corresponds to the JSON property gtins
572 573 574 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 572 def gtins @gtins end |
#is_incentivized_review ⇒ Boolean Also known as: is_incentivized_review?
Optional. Indicates whether the review is incentivized.
Corresponds to the JSON property isIncentivizedReview
577 578 579 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 577 def is_incentivized_review @is_incentivized_review end |
#is_spam ⇒ Boolean Also known as: is_spam?
Optional. Indicates whether the review is marked as spam in the publisher's
system.
Corresponds to the JSON property isSpam
584 585 586 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 584 def is_spam @is_spam end |
#is_verified_purchase ⇒ Boolean Also known as: is_verified_purchase?
Optional. Indicates whether the reviewer's purchase is verified.
Corresponds to the JSON property isVerifiedPurchase
590 591 592 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 590 def is_verified_purchase @is_verified_purchase end |
#max_rating ⇒ Fixnum
Optional. The maximum possible number for the rating. The value of the max
rating must be greater than the value of the min attribute.
Corresponds to the JSON property maxRating
597 598 599 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 597 def @max_rating end |
#min_rating ⇒ Fixnum
Optional. Contains the ratings associated with the review. The minimum
possible number for the rating. This should be the worst possible rating and
should not be a value for no rating.
Corresponds to the JSON property minRating
604 605 606 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 604 def @min_rating end |
#mpns ⇒ Array<String>
Optional. Contains MPNs (manufacturer part numbers) associated with a product.
Corresponds to the JSON property mpns
609 610 611 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 609 def mpns @mpns end |
#product_links ⇒ Array<String>
Optional. The URI of the product. This URI can have the same value as the
review_link element, if the review URI and the product URI are the same.
Corresponds to the JSON property productLinks
615 616 617 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 615 def product_links @product_links end |
#product_names ⇒ Array<String>
Optional. Descriptive name of a product.
Corresponds to the JSON property productNames
620 621 622 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 620 def product_names @product_names end |
#pros ⇒ Array<String>
Optional. Contains the advantages based on the opinion of the reviewer. Omit
boilerplate text like "pro:" unless it was written by the reviewer.
Corresponds to the JSON property pros
626 627 628 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 626 def pros @pros end |
#publisher_favicon ⇒ String
Optional. A link to the company favicon of the publisher. The image dimensions
should be favicon size: 16x16 pixels. The image format should be GIF, JPG or
PNG.
Corresponds to the JSON property publisherFavicon
633 634 635 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 633 def publisher_favicon @publisher_favicon end |
#publisher_name ⇒ String
Optional. The name of the publisher of the product reviews. The information
about the publisher, which may be a retailer, manufacturer, reviews service
company, or any entity that publishes product reviews.
Corresponds to the JSON property publisherName
640 641 642 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 640 def publisher_name @publisher_name end |
#rating ⇒ Float
Optional. The reviewer's overall rating of the product.
Corresponds to the JSON property rating
645 646 647 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 645 def @rating end |
#review_country ⇒ String
Optional. The country of the review defined by ISO 3166-1 Alpha-2 Country Code.
Corresponds to the JSON property reviewCountry
650 651 652 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 650 def review_country @review_country end |
#review_language ⇒ String
Optional. The language of the review defined by BCP-47 language code.
Corresponds to the JSON property reviewLanguage
655 656 657 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 655 def review_language @review_language end |
#review_link ⇒ Google::Apis::MerchantapiReviewsV1beta::ReviewLink
The URI of the review landing page.
Corresponds to the JSON property reviewLink
660 661 662 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 660 def review_link @review_link end |
#review_time ⇒ String
Required. The timestamp indicating when the review was written.
Corresponds to the JSON property reviewTime
665 666 667 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 665 def review_time @review_time end |
#reviewer_id ⇒ String
Optional. The author of the product review. A permanent, unique identifier for
the author of the review in the publisher's system.
Corresponds to the JSON property reviewerId
671 672 673 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 671 def reviewer_id @reviewer_id end |
#reviewer_image_links ⇒ Array<String>
Optional. A URI to an image of the reviewed product created by the review
author. The URI does not have to end with an image file extension.
Corresponds to the JSON property reviewerImageLinks
677 678 679 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 677 def reviewer_image_links @reviewer_image_links end |
#reviewer_is_anonymous ⇒ Boolean Also known as: reviewer_is_anonymous?
Optional. Set to true if the reviewer should remain anonymous.
Corresponds to the JSON property reviewerIsAnonymous
682 683 684 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 682 def reviewer_is_anonymous @reviewer_is_anonymous end |
#reviewer_username ⇒ String
Optional. The name of the reviewer of the product review.
Corresponds to the JSON property reviewerUsername
688 689 690 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 688 def reviewer_username @reviewer_username end |
#skus ⇒ Array<String>
Optional. Contains SKUs (stock keeping units) associated with a product. Often
this matches the product Offer Id in the product feed.
Corresponds to the JSON property skus
694 695 696 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 694 def skus @skus end |
#subclient_name ⇒ String
Optional. The name of the subclient of the product reviews. The subclient is
an identifier of the product review source. It should be equivalent to the
directory provided in the file data source path.
Corresponds to the JSON property subclientName
701 702 703 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 701 def subclient_name @subclient_name end |
#title ⇒ String
Optional. The title of the review.
Corresponds to the JSON property title
706 707 708 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 706 def title @title end |
#transaction_id ⇒ String
Optional. A permanent, unique identifier for the transaction associated with
the review in the publisher's system. This ID can be used to indicate that
multiple reviews are associated with the same transaction.
Corresponds to the JSON property transactionId
713 714 715 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 713 def transaction_id @transaction_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 720 def update!(**args) @aggregator_name = args[:aggregator_name] if args.key?(:aggregator_name) @asins = args[:asins] if args.key?(:asins) @brands = args[:brands] if args.key?(:brands) @collection_method = args[:collection_method] if args.key?(:collection_method) @cons = args[:cons] if args.key?(:cons) @content = args[:content] if args.key?(:content) @gtins = args[:gtins] if args.key?(:gtins) @is_incentivized_review = args[:is_incentivized_review] if args.key?(:is_incentivized_review) @is_spam = args[:is_spam] if args.key?(:is_spam) @is_verified_purchase = args[:is_verified_purchase] if args.key?(:is_verified_purchase) @max_rating = args[:max_rating] if args.key?(:max_rating) @min_rating = args[:min_rating] if args.key?(:min_rating) @mpns = args[:mpns] if args.key?(:mpns) @product_links = args[:product_links] if args.key?(:product_links) @product_names = args[:product_names] if args.key?(:product_names) @pros = args[:pros] if args.key?(:pros) @publisher_favicon = args[:publisher_favicon] if args.key?(:publisher_favicon) @publisher_name = args[:publisher_name] if args.key?(:publisher_name) @rating = args[:rating] if args.key?(:rating) @review_country = args[:review_country] if args.key?(:review_country) @review_language = args[:review_language] if args.key?(:review_language) @review_link = args[:review_link] if args.key?(:review_link) @review_time = args[:review_time] if args.key?(:review_time) @reviewer_id = args[:reviewer_id] if args.key?(:reviewer_id) @reviewer_image_links = args[:reviewer_image_links] if args.key?(:reviewer_image_links) @reviewer_is_anonymous = args[:reviewer_is_anonymous] if args.key?(:reviewer_is_anonymous) @reviewer_username = args[:reviewer_username] if args.key?(:reviewer_username) @skus = args[:skus] if args.key?(:skus) @subclient_name = args[:subclient_name] if args.key?(:subclient_name) @title = args[:title] if args.key?(:title) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) end |