Class: Google::Apis::MerchantapiReviewsV1beta::ProductReviewItemLevelIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb

Overview

The ItemLevelIssue of the product review status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductReviewItemLevelIssue

Returns a new instance of ProductReviewItemLevelIssue.



819
820
821
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributeString

Output only. The attribute's name, if the issue is caused by a single attribute. Corresponds to the JSON property attribute

Returns:

  • (String)


782
783
784
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 782

def attribute
  @attribute
end

#codeString

Output only. The error code of the issue. Corresponds to the JSON property code

Returns:

  • (String)


787
788
789
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 787

def code
  @code
end

#descriptionString

Output only. A short issue description in English. Corresponds to the JSON property description

Returns:

  • (String)


792
793
794
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 792

def description
  @description
end

#detailString

Output only. A detailed issue description in English. Corresponds to the JSON property detail

Returns:

  • (String)


797
798
799
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 797

def detail
  @detail
end

#documentationString

Output only. The URL of a web page to help with resolving this issue. Corresponds to the JSON property documentation

Returns:

  • (String)


802
803
804
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 802

def documentation
  @documentation
end

#reporting_contextString

Output only. The reporting context the issue applies to. Corresponds to the JSON property reportingContext

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 807

def reporting_context
  @reporting_context
end

#resolutionString

Output only. Whether the issue can be resolved by the merchant. Corresponds to the JSON property resolution

Returns:

  • (String)


812
813
814
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 812

def resolution
  @resolution
end

#severityString

Output only. How this issue affects serving of the product review. Corresponds to the JSON property severity

Returns:

  • (String)


817
818
819
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 817

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



824
825
826
827
828
829
830
831
832
833
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 824

def update!(**args)
  @attribute = args[:attribute] if args.key?(:attribute)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
  @detail = args[:detail] if args.key?(:detail)
  @documentation = args[:documentation] if args.key?(:documentation)
  @reporting_context = args[:reporting_context] if args.key?(:reporting_context)
  @resolution = args[:resolution] if args.key?(:resolution)
  @severity = args[:severity] if args.key?(:severity)
end