Class: Google::Apis::MerchantapiReviewsV1beta::ProductStatusChangeMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb

Overview

The message that the merchant will receive to notify about product status change event

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductStatusChangeMessage

Returns a new instance of ProductStatusChangeMessage.



931
932
933
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accountString

The target account that owns the entity that changed. Format : accounts/ merchant_id` Corresponds to the JSON propertyaccount`

Returns:

  • (String)


884
885
886
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 884

def 
  @account
end

#attributeString

The attribute in the resource that changed, in this case it will be always Status. Corresponds to the JSON property attribute

Returns:

  • (String)


890
891
892
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 890

def attribute
  @attribute
end

#changesArray<Google::Apis::MerchantapiReviewsV1beta::ProductChange>

A message to describe the change that happened to the product Corresponds to the JSON property changes



895
896
897
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 895

def changes
  @changes
end

#event_timeString

The time at which the event was generated. If you want to order the notification messages you receive you should rely on this field not on the order of receiving the notifications. Corresponds to the JSON property eventTime

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 902

def event_time
  @event_time
end

#expiration_timeString

Optional. The product expiration time. This field will not be set if the notification is sent for a product deletion event. Corresponds to the JSON property expirationTime

Returns:

  • (String)


908
909
910
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 908

def expiration_time
  @expiration_time
end

#managing_accountString

The account that manages the merchant's account. can be the same as merchant id if it is standalone account. Format : accounts/service_provider_id` Corresponds to the JSON propertymanagingAccount`

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 914

def 
  @managing_account
end

#resourceString

The product name. Format: accounts/account/products/product` Corresponds to the JSON propertyresource`

Returns:

  • (String)


919
920
921
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 919

def resource
  @resource
end

#resource_idString

The product id. Corresponds to the JSON property resourceId

Returns:

  • (String)


924
925
926
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 924

def resource_id
  @resource_id
end

#resource_typeString

The resource that changed, in this case it will always be Product. Corresponds to the JSON property resourceType

Returns:

  • (String)


929
930
931
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 929

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



936
937
938
939
940
941
942
943
944
945
946
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 936

def update!(**args)
  @account = args[:account] if args.key?(:account)
  @attribute = args[:attribute] if args.key?(:attribute)
  @changes = args[:changes] if args.key?(:changes)
  @event_time = args[:event_time] if args.key?(:event_time)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @managing_account = args[:managing_account] if args.key?(:managing_account)
  @resource = args[:resource] if args.key?(:resource)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end