Class: Google::Apis::MerchantapiReviewsV1beta::ProductReview
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReviewsV1beta::ProductReview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb
Overview
A review for a product. For more information, see Introduction to Product Review Feeds
Instance Attribute Summary collapse
-
#custom_attributes ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::CustomAttribute>
Optional.
-
#data_source ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#product_review_attributes ⇒ Google::Apis::MerchantapiReviewsV1beta::ProductReviewAttributes
Attributes.
-
#product_review_id ⇒ String
Required.
-
#product_review_status ⇒ Google::Apis::MerchantapiReviewsV1beta::ProductReviewStatus
Product review status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductReview
constructor
A new instance of ProductReview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductReview
Returns a new instance of ProductReview.
513 514 515 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_attributes ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::CustomAttribute>
Optional. A list of custom (merchant-provided) attributes.
Corresponds to the JSON property customAttributes
484 485 486 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 484 def custom_attributes @custom_attributes end |
#data_source ⇒ String
Output only. The primary data source of the product review.
Corresponds to the JSON property dataSource
489 490 491 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 489 def data_source @data_source end |
#name ⇒ String
Identifier. The name of the product review. Format: "productreview.name=
accounts/account/productReviews/productReview"
Corresponds to the JSON property name
495 496 497 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 495 def name @name end |
#product_review_attributes ⇒ Google::Apis::MerchantapiReviewsV1beta::ProductReviewAttributes
Attributes.
Corresponds to the JSON property productReviewAttributes
500 501 502 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 500 def product_review_attributes @product_review_attributes end |
#product_review_id ⇒ String
Required. The permanent, unique identifier for the product review in the
publisher’s system.
Corresponds to the JSON property productReviewId
506 507 508 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 506 def product_review_id @product_review_id end |
#product_review_status ⇒ Google::Apis::MerchantapiReviewsV1beta::ProductReviewStatus
Product review status.
Corresponds to the JSON property productReviewStatus
511 512 513 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 511 def product_review_status @product_review_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
518 519 520 521 522 523 524 525 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 518 def update!(**args) @custom_attributes = args[:custom_attributes] if args.key?(:custom_attributes) @data_source = args[:data_source] if args.key?(:data_source) @name = args[:name] if args.key?(:name) @product_review_attributes = args[:product_review_attributes] if args.key?(:product_review_attributes) @product_review_id = args[:product_review_id] if args.key?(:product_review_id) @product_review_status = args[:product_review_status] if args.key?(:product_review_status) end |