Class: Google::Apis::MerchantapiReviewsV1beta::ProductReviewStatus
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiReviewsV1beta::ProductReviewStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_reviews_v1beta/classes.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb,
lib/google/apis/merchantapi_reviews_v1beta/representations.rb
Overview
Product review status.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#destination_statuses ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::ProductReviewDestinationStatus>
Output only.
-
#item_level_issues ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::ProductReviewItemLevelIssue>
Output only.
-
#last_update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductReviewStatus
constructor
A new instance of ProductReviewStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductReviewStatus
Returns a new instance of ProductReviewStatus.
862 863 864 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Date on which the item has been created, in ISO 8601 format.
Corresponds to the JSON property createTime
844 845 846 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 844 def create_time @create_time end |
#destination_statuses ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::ProductReviewDestinationStatus>
Output only. The intended destinations for the product review.
Corresponds to the JSON property destinationStatuses
849 850 851 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 849 def destination_statuses @destination_statuses end |
#item_level_issues ⇒ Array<Google::Apis::MerchantapiReviewsV1beta::ProductReviewItemLevelIssue>
Output only. A list of all issues associated with the product review.
Corresponds to the JSON property itemLevelIssues
854 855 856 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 854 def item_level_issues @item_level_issues end |
#last_update_time ⇒ String
Output only. Date on which the item has been last updated, in ISO 8601 format.
Corresponds to the JSON property lastUpdateTime
860 861 862 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 860 def last_update_time @last_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
867 868 869 870 871 872 |
# File 'lib/google/apis/merchantapi_reviews_v1beta/classes.rb', line 867 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @destination_statuses = args[:destination_statuses] if args.key?(:destination_statuses) @item_level_issues = args[:item_level_issues] if args.key?(:item_level_issues) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) end |